<?php
/**
 * Airtech template functions.
 *
 * @package airtech
 */

if ( ! function_exists( 'airtech_display_comments' ) ) {
	/**
	 * Airtech display comments
	 *
	 * @since  1.0.0
	 */
	function airtech_display_comments() {
		// If comments are open or we have at least one comment, load up the comment template.
		if ( comments_open() || 0 !== intval( get_comments_number() ) ) :
			comments_template();
		endif;
	}
}

if ( ! function_exists( 'airtech_comment' ) ) {
	/**
	 * Airtech comment template
	 *
	 * @param array $comment the comment array.
	 * @param array $args the comment args.
	 * @param int   $depth the comment depth.
	 * @since 1.0.0
	 */
	function airtech_comment( $comment, $args, $depth ) {
		if ( 'div' === $args['style'] ) {
			$tag       = 'div';
			$add_below = 'comment';
		} else {
			$tag       = 'li';
			$add_below = 'div-comment';
		}
		?>
		<<?php echo esc_attr( $tag ); ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?> id="comment-<?php comment_ID(); ?>">
		<div class="comment-body">
			<?php echo get_avatar( $comment, 128 ); ?>
		<?php if ( 'div' !== $args['style'] ) : ?>
		<div id="div-comment-<?php comment_ID(); ?>" class="comment-content">
		<?php endif; ?>
		<div class="comment-text">
			<div class="comment-author vcard">
			<?php printf( wp_kses_post( '<cite class="fn">%s</cite>', 'airtech' ), get_comment_author_link() ); ?>
			</div>
			<?php if ( '0' === $comment->comment_approved ) : ?>
				<em class="comment-awaiting-moderation"><?php esc_attr_e( 'Your comment is awaiting moderation.', 'airtech' ); ?></em>
				<br />
			<?php endif; ?>

		<?php comment_text(); ?>
		</div>
		<div class="comment-meta commentmetadata">
			<a href="<?php echo esc_url( htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ); ?>" class="comment-date">
				<?php echo '<time datetime="' . get_comment_date( 'c' ) . '">' . get_comment_date() . '</time>'; ?>
			</a>
		</div>
		<div class="reply">
		<?php
		comment_reply_link(
			array_merge(
				$args, array(
					'add_below' => $add_below,
					'depth'     => $depth,
					'max_depth' => $args['max_depth'],
				)
			)
		);
		?>
		<?php edit_comment_link( __( 'Edit', 'airtech' ), '  ', '' ); ?>
		</div>
		</div>
		<?php if ( 'div' !== $args['style'] ) : ?>
		</div>
		<?php endif; ?>
		<?php
	}
}

if ( ! function_exists( 'airtech_footer_widgets' ) ) {
	/**
	 * Display the footer widget regions.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function airtech_footer_widgets() {
		$rows    = intval( apply_filters( 'airtech_footer_widget_rows', 1 ) );
		$regions = intval( apply_filters( 'airtech_footer_widget_columns', 4 ) );

		for ( $row = 1; $row <= $rows; $row++ ) :

			// Defines the number of active columns in this footer row.
			for ( $region = $regions; 0 < $region; $region-- ) {
				if ( is_active_sidebar( 'footer-' . esc_attr( $region + $regions * ( $row - 1 ) ) ) ) {
					$columns = $region;
					break;
				}
			}

			if ( isset( $columns ) ) :
				?>
				<div class="footer-inner">
					<div class="col-full">
						<div class=<?php echo '"footer-widgets row-' . esc_attr( $row ) . ' col-' . esc_attr( $columns ) . ' fix"'; ?>>
						<?php
						for ( $column = 1; $column <= $columns; $column++ ) :
							$footer_n = $column + $regions * ( $row - 1 );

							if ( is_active_sidebar( 'footer-' . esc_attr( $footer_n ) ) ) :
								?>
							<div class="block footer-widget-<?php echo esc_attr( $column ); ?>">
								<?php dynamic_sidebar( 'footer-' . esc_attr( $footer_n ) ); ?>
							</div>
								<?php
							endif;
						endfor;
						?>
						</div><!-- .footer-widgets.row-<?php echo esc_attr( $row ); ?> -->
					</div><!-- .col-full -->
				</div><!-- .footer-inner -->
				<?php
				unset( $columns );
			endif;
		endfor;
	}
}

if ( ! function_exists( 'airtech_credit' ) ) {
	/**
	 * Display the theme credit
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function airtech_credit() {
		?>
		<div class="site-info">
			<?php echo esc_html( apply_filters( 'airtech_copyright_text', $content = '&copy; ' . get_bloginfo( 'name' ) . ' ' . date( 'Y' ) ) ); ?>
			<?php if ( apply_filters( 'airtech_credit_link', true ) ) { ?>
			<br />
				<?php
				if ( apply_filters( 'airtech_privacy_policy_link', true ) && function_exists( 'the_privacy_policy_link' ) ) {
					the_privacy_policy_link( '', '<span role="separator" aria-hidden="true"></span>' );
				}
				?>
				<?php echo '<a href="https://woocommerce.com" target="_blank" title="' . esc_attr__( 'WooCommerce - The Best eCommerce Platform for WordPress', 'airtech' ) . '" rel="author">' . esc_html__( 'Built with Airtech &amp; WooCommerce', 'airtech' ) . '</a>.'; ?>
			<?php } ?>
		</div><!-- .site-info -->
		<?php
	}
}

if ( ! function_exists( 'airtech_header_widget_region' ) ) {
	/**
	 * Display header widget region
	 *
	 * @since  1.0.0
	 */
	function airtech_header_widget_region() {
		if ( is_active_sidebar( 'header-1' ) ) {
			?>
		<div class="header-widget-region" role="complementary">
			<div class="col-full">
				<?php dynamic_sidebar( 'header-1' ); ?>
			</div>
		</div>
			<?php
		}
	}
}

if ( ! function_exists( 'airtech_site_branding' ) ) {
	/**
	 * Site branding wrapper and display
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function airtech_site_branding() {
		?>
		<div class="site-branding">
			<?php airtech_site_title_or_logo(); ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'airtech_site_title_or_logo' ) ) {
	/**
	 * Display the site title or logo
	 *
	 * @since 2.1.0
	 * @param bool $echo Echo the string or return it.
	 * @return string
	 */
	function airtech_site_title_or_logo( $echo = true ) {
		if ( function_exists( 'the_custom_logo' ) && has_custom_logo() ) {
			$logo = get_custom_logo();
			$html = is_home() ? '<h1 class="logo">' . $logo . '</h1>' : $logo;
		} else {
			$tag = is_home() ? 'h1' : 'div';

			$html = '<' . esc_attr( $tag ) . ' class="beta site-title"><a href="' . esc_url( home_url( '/' ) ) . '" rel="home">' . esc_html( get_bloginfo( 'name' ) ) . '</a></' . esc_attr( $tag ) . '>';

			if ( '' !== get_bloginfo( 'description' ) ) {
				$html .= '<p class="site-description">' . esc_html( get_bloginfo( 'description', 'display' ) ) . '</p>';
			}
		}

		if ( ! $echo ) {
			return $html;
		}

		echo wp_kses_post($html); // WPCS: XSS ok.
	}
}

if ( ! function_exists( 'airtech_primary_navigation' ) ) {
	/**
	 * Display Primary Navigation
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function airtech_primary_navigation() {
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php esc_html_e( 'Primary Navigation', 'airtech' ); ?>">
		<button class="menu-toggle" aria-controls="site-navigation" aria-expanded="false"><span><?php echo esc_attr( apply_filters( 'airtech_menu_toggle_text', __( 'Menu', 'airtech' ) ) ); ?></span></button>
                <?php wp_nav_menu(
                        array(
                            'depth'             => 3,
                            'theme_location'    => 'primary-menu',
							'container_class' => 'primary-navigation',
                            //'menu_class'        => 'nav navbar-nav navigation-box',
                            //'fallback_cb'       => '',
                            //'menu_id'           => '',
							//'walker'          => new Airtech_WP_Bootstrap_Navwalker(),
                        )
                ); ?>
                <!-- The WordPress Menu goes here -->
		</nav><!-- #site-navigation -->
		<?php
	}
}

if ( ! function_exists( 'airtech_skip_links' ) ) {
	/**
	 * Skip links
	 *
	 * @since  1.4.1
	 * @return void
	 */
	function airtech_skip_links() {
		?>
		<a class="skip-link screen-reader-text" href="#site-navigation"><?php esc_attr_e( 'Skip to navigation', 'airtech' ); ?></a>
		<a class="skip-link screen-reader-text" href="#content"><?php esc_attr_e( 'Skip to content', 'airtech' ); ?></a>
		<?php
	}
}

if ( ! function_exists( 'airtech_homepage_header' ) ) {
	/**
	 * Display the page header without the featured image
	 *
	 * @since 1.0.0
	 */
	function airtech_homepage_header() {
		edit_post_link( __( 'Edit this section', 'airtech' ), '', '', '', 'button airtech-hero__button-edit' );
		?>
		<header class="entry-header">
			<?php
			the_title( '<h1 class="entry-title">', '</h1>' );
			?>
		</header><!-- .entry-header -->
		<?php
	}
}

if ( ! function_exists( 'airtech_page_header' ) ) {
	/**
	 * Display the page header
	 *
	 * @since 1.0.0
	 */
	function airtech_page_header() {
		?>
		<header class="entry-header">
			<?php
			airtech_post_thumbnail( 'full' );
			the_title( '<h1 class="entry-title">', '</h1>' );
			?>
		</header><!-- .entry-header -->
		<?php
	}
}

if ( ! function_exists( 'airtech_page_content' ) ) {
	/**
	 * Display the post content
	 *
	 * @since 1.0.0
	 */
	function airtech_page_content() {
		?>
		<div class="entry-content">
			<?php the_content(); ?>
			<?php
				wp_link_pages(
					array(
						'before' => '<div class="page-links">' . __( 'Pages:', 'airtech' ),
						'after'  => '</div>',
					)
				);
			?>
		</div><!-- .entry-content -->
		<?php
	}
}

if ( ! function_exists( 'airtech_post_header' ) ) {
	/**
	 * Display the post header with a link to the single post
	 *
	 * @since 1.0.0
	 */
	function airtech_post_header() {
		?>
		<header class="entry-header">
		<?php
		do_action( 'airtech_post_header_before' );

		if ( is_single() ) {
			the_title( '<h1 class="entry-title">', '</h1>' );
		} else {
			the_title( sprintf( '<h2 class="alpha entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' );
		}

		do_action( 'airtech_post_header_after' );
		?>
		<?php airtech_post_meta(); ?>
		</header><!-- .entry-header -->
		<?php
	}
}

if ( ! function_exists( 'airtech_post_content' ) ) {
	/**
	 * Display the post content with a link to the single post
	 *
	 * @since 1.0.0
	 */
	function airtech_post_content() {
		?>
		<div class="entry-content">
		<?php

		do_action( 'airtech_post_content_before' );

		if ( is_single() ) {
			the_content(
				sprintf(
					/* translators: %s: post title */
					__( 'Continue reading %s', 'airtech' ),
					'<span class="screen-reader-text">' . get_the_title() . '</span>'
				)
			);
		} else {
			the_excerpt();
			echo '<a href="'. get_the_permalink() .'" class="button">'. esc_html__('Read more', 'airtech') .'</a>';
		}

		do_action( 'airtech_post_content_after' );

		wp_link_pages(
			array(
				'before' => '<div class="page-links">' . __( 'Pages:', 'airtech' ),
				'after'  => '</div>',
			)
		);
		?>
		</div><!-- .entry-content -->
		<?php
	}
}

if ( ! function_exists( 'airtech_post_meta' ) ) {
	/**
	 * Display the post meta
	 *
	 * @since 1.0.0
	 */
	function airtech_post_meta() {
		if ( 'post' !== get_post_type() ) {
			return;
		}

		// Posted on.
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

		$output_time_string = sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>', esc_url( get_permalink() ), $time_string );

		$posted_on = '
			<span class="posted-on"><i class="fa fa-calendar" aria-hidden="true"></i>' .
			/* translators: %s: post date */
			sprintf( __( 'Posted on %s', 'airtech' ), $output_time_string ) .
			'</span>';

		// Author.
		$author = sprintf(
			'<span class="post-author"><i class="fa fa-user" aria-hidden="true"></i> %1$s <a href="%2$s" class="url fn" rel="author">%3$s</a></span>',
			__( 'By', 'airtech' ),
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_html( get_the_author() )
		);

		// Comments.
		$comments = '';

		if ( ! post_password_required() && ( comments_open() || 0 !== intval( get_comments_number() ) ) ) {
			$comments_number = get_comments_number_text( __( 'Leave a comment', 'airtech' ), __( '1 Comment', 'airtech' ), __( '% Comments', 'airtech' ) );

			$comments = sprintf(
				'<span class="post-comments"><i class="fa fa-comments-o" aria-hidden="true"></i> <a href="%1$s">%2$s</a></span>',
				esc_url( get_comments_link() ),
				$comments_number
			);
		}

		echo wp_kses(
			sprintf( '<div class="entry-meta">%1$s %2$s %3$s</div>', $author, $posted_on, $comments ), airtech_blv_allowed_tags()
		);
	}
}

if ( ! function_exists( 'airtech_post_taxonomy' ) ) {
	/**
	 * Display the post taxonomies
	 *
	 * @since 2.4.0
	 */
	function airtech_post_taxonomy() {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( ', ' );

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( ', ' );
		?>

		<aside class="entry-taxonomy">
			<?php if ( $categories_list ) : ?>
			<div class="cat-links">
				<?php echo esc_html__( 'Categories:', 'airtech' ); ?> <?php echo wp_kses_post( $categories_list ); ?>
			</div>
			<?php endif; ?>

			<?php if ( $tags_list ) : ?>
			<div class="tags-links">
				<?php echo esc_html( _n( 'Tag:', 'Tags:', count( get_the_tags() ), 'airtech' ) ); ?> <?php echo wp_kses_post( $tags_list ); ?>
			</div>
			<?php endif; ?>
		</aside>

		<?php
	}
}

if ( ! function_exists( 'airtech_paging_nav' ) ) {
	/**
	 * Display navigation to next/previous set of posts when applicable.
	 */
	function airtech_paging_nav() {
		global $wp_query;

		$args = array(
			'type'      => 'list',
			'next_text' => _x( 'Next', 'Next post', 'airtech' ),
			'prev_text' => _x( 'Previous', 'Previous post', 'airtech' ),
		);

		the_posts_pagination( $args );
	}
}

if ( ! function_exists( 'airtech_post_nav' ) ) {
	/**
	 * Display navigation to next/previous post when applicable.
	 */
	function airtech_post_nav() {
		$args = array(
			'next_text' => '<span class="screen-reader-text">' . esc_html__( 'Next post:', 'airtech' ) . ' </span>%title',
			'prev_text' => '<span class="screen-reader-text">' . esc_html__( 'Previous post:', 'airtech' ) . ' </span>%title',
		);
		the_post_navigation( $args );
	}
}

if ( ! function_exists( 'airtech_posted_on' ) ) {
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 *
	 * @deprecated 2.4.0
	 */
	function airtech_posted_on() {
		_deprecated_function( 'airtech_posted_on', '2.4.0' );
	}
}

if ( ! function_exists( 'airtech_homepage_content' ) ) {
	/**
	 * Display homepage content
	 * Hooked into the `homepage` action in the homepage template
	 *
	 * @since  1.0.0
	 * @return  void
	 */
	function airtech_homepage_content() {
		while ( have_posts() ) {
			the_post();

			get_template_part( 'template-parts/content', 'homepage' );

		} // end of the loop.
	}
}

if ( ! function_exists( 'airtech_social_icons' ) ) {
	/**
	 * Display social icons
	 * If the subscribe and connect plugin is active, display the icons.
	 *
	 * @link http://wordpress.org/plugins/subscribe-and-connect/
	 * @since 1.0.0
	 */
	function airtech_social_icons() {
		if ( class_exists( 'Subscribe_And_Connect' ) ) {
			echo '<div class="subscribe-and-connect-connect">';
			subscribe_and_connect_connect();
			echo '</div>';
		}
	}
}

if ( ! function_exists( 'airtech_get_sidebar' ) ) {
	/**
	 * Display airtech sidebar
	 *
	 * @uses get_sidebar()
	 * @since 1.0.0
	 */
	function airtech_get_sidebar() {

		if ( class_exists( 'WooCommerce' ) && airtech_is_woocommerce_page() ) {
			get_sidebar('shop');
		}
		else {
			get_sidebar();
		}
	}
}

if ( ! function_exists( 'airtech_get_shop_sidebar' ) ) {
	/**
	 * Display airtech shop sidebar
	 *
	 * @uses get_sidebar()
	 * @since 1.0.0
	 */
	function airtech_get_shop_sidebar() {
		get_sidebar('shop');
	}
}

if ( ! function_exists( 'airtech_get_product_sidebar' ) ) {
	/**
	 * Display airtech product sidebar
	 *
	 * @uses get_sidebar()
	 * @since 1.0.0
	 */
	function airtech_get_product_sidebar() {
		get_sidebar('product');
	}
}

if ( ! function_exists( 'airtech_post_thumbnail' ) ) {
	/**
	 * Display post thumbnail
	 *
	 * @var $size thumbnail size. thumbnail|medium|large|full|$custom
	 * @uses has_post_thumbnail()
	 * @uses the_post_thumbnail
	 * @param string $size the post thumbnail size.
	 * @since 1.5.0
	 */
	function airtech_post_thumbnail( $size = 'full' ) {
		if ( has_post_thumbnail() ) {
			echo '<a href="'.get_the_permalink().'" class="blog_img">';
			    the_post_thumbnail( $size );
			echo '</a>';

		}
	}
}

if ( ! function_exists( 'airtech_primary_navigation_wrapper' ) ) {
	/**
	 * The primary navigation wrapper
	 */
	function airtech_primary_navigation_wrapper() {
		echo '<div class="airtech-primary-navigation"><div class="col-full">';
	}
}

if ( ! function_exists( 'airtech_primary_navigation_wrapper_close' ) ) {
	/**
	 * The primary navigation wrapper close
	 */
	function airtech_primary_navigation_wrapper_close() {
		echo '</div></div>';
	}
}

if ( ! function_exists( 'airtech_header_container' ) ) {
	/**
	 * The header container
	 */
	function airtech_header_container() {
		echo '<div class="col-full">';
	}
}

if ( ! function_exists( 'airtech_header_container_close' ) ) {
	/**
	 * The header container close
	 */
	function airtech_header_container_close() {
		echo '</div>';
	}
}

if ( ! function_exists( 'airtech_create_sc' ) ) {
	/**
	 * Create shortcode.
	 */
	function airtech_create_sc() {

		/* Adding bolvo breadcrumb SC */
		if ( function_exists( 'woocommerce_breadcrumb' ) && function_exists( 'bolvo_add_sc' ) ) {
			bolvo_add_sc('bolvo_breadcrumb', 'woocommerce_breadcrumb');
		}

		/* Adding bolvo header cart SC */
		if ( function_exists( 'airtech_header_cart' ) && function_exists( 'bolvo_add_sc' ) ) {
			bolvo_add_sc('airtech_cart', 'airtech_header_cart');
		}
bolvo_add_sc('airtech_megamenu', 'airtech_megamenu');
	}
}


/**
 * build megamenu
 */
if(!( function_exists('airtech_megamenu') )) {
	function airtech_megamenu() {
	if ( ! function_exists( 'bolvo_add_sc' ) ) return; // nothing left to do.

	$settings = get_theme_mod( 'menu_items' );
		?>

		<li class="dropdown submenu mega_menu tab-demo">
			<a class="dropdown-toggle" data-toggle="dropdown" href="<?php echo esc_url(get_theme_mod( 'menu_link' )); ?>" role="button" aria-haspopup="true" aria-expanded="false">
				<?php echo wp_kses(get_theme_mod( 'menu_title' ), airtech_blv_allowed_tags() ); ?>
			</a>
			<?php if( is_array( $settings )) { ?>
			<ul class="dropdown-menu">
				<div class="row">
					<?php foreach( $settings as $setting ) : ?>
					<div class="col-lg-4 tabHeader">
						<ul class="nav flex-column nav-pills" id="v-pills-tab" role="tablist" aria-orientation="vertical">
							<li class="active">
								<a class="nav-link active" id="<?php echo sanitize_title($setting( 'menu_text' ));?>-tab" data-toggle="pill" href="#<?php echo sanitize_title($setting( 'menu_text' ));?>" role="tab" aria-controls="<?php echo sanitize_title($setting( 'menu_text' ));?>" aria-selected="true"><?php echo wp_kses($setting( 'menu_text' ), airtech_blv_allowed_tags() ); ?></a>
							</li>
						</ul>
					</div>

					<div class="col-lg-8">
						<div class="tab-content tabContent" id="v-pills-tabContent">
							<div class="tab-pane fade show active" id="<?php echo sanitize_title($setting( 'menu_text' ));?>" role="tabpanel" aria-labelledby="<?php echo sanitize_title($setting( 'menu_text' ));?>-tab">
								<?php if( '' == $setting( 'menu_para1_val' ) ) { ?>
								<p><?php echo wp_kses_post( $setting( 'menu_para1_val' ) ); ?></p>
								<?php } ?>
								<?php if( '' == $setting( 'menu_para2_val' ) ) { ?>
								<p><?php echo wp_kses_post( $setting( 'menu_para2_val' ) ); ?></p>
								<?php } ?>
								<?php if( '' == $setting( 'menu_button_val' ) ) { ?>
								<?php echo wp_kses_post( $setting( 'menu_button_val' ) ); ?>
								<?php $menu_button_vals = explode('##', $setting( 'menu_button_val' )); ?>
								<a class="product_btn" href="<?php echo esc_url($menu_button_vals['0']); ?>">
									<?php echo wp_kses($menu_button_vals['1'], airtech_blv_allowed_tags() ); ?>
								</a>
								<?php } ?>
								<?php if( '' != $setting( 'menu_list_val' ) ) { ?>
								<?php
									$menu_lists = preg_split ('/$\R?^/m', $setting( 'menu_list_val' ));
									echo '<ul class="nav flex-column">';
									foreach( $menu_lists as $menu_list ) :
										$menu_list_items = explode('##', $menu_list);
										echo '<li><a href="' .esc_url($menu_list_items['0']) .'">' . wp_kses($menu_list_items['1'], airtech_blv_allowed_tags() ) .'</a></li>';
									endforeach;
									echo '</ul>';
									?>
								<ul class="nav flex-column">
									<li><a href="financial.html">Banking &amp; Financial</a></li>
								</ul>
								<?php } ?>
							</div>
						</div>
					</div>
				    <?php endforeach; ?>
				</div>
			</ul>
			<?php } ?>
		</li>

		<?php
		if ( function_exists( 'bolvo_add_sc' ) ) {

		}
	}

}

